pilas.actores.moneda

Package pilas :: Package actores :: Module moneda |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.moneda

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  import pilas
    10  from pilas.actores import Animacion
    11
    12 -class Moneda(Animacion):
    13      """Representa una moneda con animación.
    14
    15      .. image:: images/actores/moneda.png
    16
    17      Ejemplo:
    18
    19          >>> moneda = pilas.actores.Moneda()
    20
    21      """
    22
    23 -    def __init__(self, x=0, y=0):
    24          """Constructor de la moneda
    25
    26          :param x: Posición horizontal del moneda.
    27          :type x: int
    28          :param y: Posición vertical del moneda.
    29          :type y: int
    30
    31          """
    32          Animacion.__init__(self, pilas.imagenes.cargar_grilla("moneda.png", 8), ciclica=True, x=x, y=y)
    33